@@ -33,7 +33,7 @@ import os.path
 import numpy as np
 import numpy.linalg as npla
 import scipy.linalg as scla
-import pickle as pkl
+import cPickle as pkl
 
 class NumericsError(Exception):
     def __init__(self, value):
